# coding: utf-8

"""
    MONEI API v1

    The MONEI API is organized around [REST](https://en.wikipedia.org/wiki/Representational_State_Transfer). Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs. <br/><br/> **Base URL:** https://api.monei.com/v1 <br/><br/> **Client libraries:** <ul>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li>   <li><a target=\"_blank\" href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>  # noqa: E501

    The version of the OpenAPI document: 1.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import Monei
from Monei.api.subscriptions_api import SubscriptionsApi  # noqa: E501
from Monei.rest import ApiException


class TestSubscriptionsApi(unittest.TestCase):
    """SubscriptionsApi unit test stubs"""

    def setUp(self):
        self.api = Monei.api.subscriptions_api.SubscriptionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate(self):
        """Test case for activate

        Activate Subscription  # noqa: E501
        """
        pass

    def test_cancel(self):
        """Test case for cancel

        Cancel Subscription  # noqa: E501
        """
        pass

    def test_create(self):
        """Test case for create

        Create Subscription  # noqa: E501
        """
        pass

    def test_get(self):
        """Test case for get

        Get Subscription  # noqa: E501
        """
        pass

    def test_pause(self):
        """Test case for pause

        Pause Subscription  # noqa: E501
        """
        pass

    def test_resume(self):
        """Test case for resume

        Resume Subscription  # noqa: E501
        """
        pass

    def test_update(self):
        """Test case for update

        Update Subscription  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
