# coding: utf-8

"""
    MONEI API v1

    The MONEI API is organized around [REST](https://en.wikipedia.org/wiki/Representational_State_Transfer). Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import MONEI PYTHON SDK
from MONEI PYTHON SDK.api.payments_api import PaymentsApi  # noqa: E501
from MONEI PYTHON SDK.rest import ApiException


class TestPaymentsApi(unittest.TestCase):
    """PaymentsApi unit test stubs"""

    def setUp(self):
        self.api = MONEI PYTHON SDK.api.payments_api.PaymentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel(self):
        """Test case for cancel

        Cancel Payment  # noqa: E501
        """
        pass

    def test_capture(self):
        """Test case for capture

        Capture Payment  # noqa: E501
        """
        pass

    def test_confirm(self):
        """Test case for confirm

        Confirm Payment  # noqa: E501
        """
        pass

    def test_create(self):
        """Test case for create

        Create Payment  # noqa: E501
        """
        pass

    def test_get(self):
        """Test case for get

        Get Payment  # noqa: E501
        """
        pass

    def test_recurring(self):
        """Test case for recurring

        Recurring Payment  # noqa: E501
        """
        pass

    def test_refund(self):
        """Test case for refund

        Refund Payment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
